package cn.com.countrygarden.bi.main.dao.personnel;

import cn.com.countrygarden.bi.main.core.Mapper;
import cn.com.countrygarden.bi.main.core.Result;
import cn.com.countrygarden.bi.main.dto.LabelVo;
import cn.com.countrygarden.bi.main.dto.PersonInfoVO;
import cn.com.countrygarden.bi.main.dto.personnel.CampusevaluationDTO;
import cn.com.countrygarden.bi.main.dto.personnel.PersonnelAdvisorDTO;
import cn.com.countrygarden.bi.main.dto.personnel.PersonnelAppDTO;
import cn.com.countrygarden.bi.main.model.personnel.Personnel;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 人才信息-数据层
 *
 * @author 李森林
 * @email www.justintoforest@gamail.com
 * @date 2018-07-10
 */
public interface PersonnelMapper extends Mapper<Personnel>{

    List<LabelVo> selectInfomationByUid(@Param("name") String name,@Param("userId") String userId);

    LabelVo selectByUid(String uid);

    List<PersonInfoVO> personInfoCodeOrId(@Param("search") String search);
    //    List<PersonnelAppDTO> selectByUids(@Param("uids")String[] uids);
    List<PersonnelAppDTO> selectByUids2(@Param("uids")String[] uids);
    //
    List<PersonnelAdvisorDTO> findPersonnelAdvisorDTO(@Param("personnelId")int personnelId,@Param("Type")String Type);

    Personnel perone(@Param("userId") String userId);

    Personnel peroneid(@Param("id") Integer id);

    List<LabelVo> selectByUids(@Param("uids")String[] uids);

    List<PersonInfoVO> selectByPersonInfoByCodeOrName(@Param("search")String search,@Param("userIds") List<String> userIds,@Param("userquyu")String userquyu);

    Double find270Info(@Param("uid")String uid, @Param("problemIds")List<Integer> problemIds);

    List<Integer> findProblemIds(@Param("classId")Integer classId);

    List<CampusevaluationDTO> findPersonnelCampusevaluation(@Param("personnelId")Integer personnelId);
    
    List<Personnel> selectnull();
}